"""Custom scrapy extensions."""
import logging
import re

from scrapy.extensions.throttle import AutoThrottle
from scrapy.http import Response


class CustomDelayThrottle(AutoThrottle):
    """Set custom `DOWNLOAD_DELAY`for different url regex."""

    def __init__(self, crawler):
        """Initialize the custom delay throttle."""
        self.urlRegex_delays: dict = crawler.settings.getdict('DOMAIN_DELAYS')
        logging.debug('Using Custom delay for each url regex')
        super().__init__(crawler)

    def _adjust_delay(self, slot, latency: float, response: Response):
        """Override AutoThrottle._adjust_delay()."""
        for regex, delay in self.urlRegex_delays.items():
            if re.match(regex, response.url):
                slot.delay = delay
                break



"""Package this project."""
from setuptools import find_packages, setup

from scrapy_domain_delay import __version__


setup(
    name='scrapy-custom-delay',
    version=__version__,
    project_urls={
        'Source': 'https://github.com/653603927/scrapy-custom-delay',
    },
    description=(
        'This package provides a way to let '
        'you set different delay for different '
        'website, using the Scrapy framework.'
    ),
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    packages=find_packages(),
    author='LiuXiaotong',
    author_email='lxtxiaotong@foxmail.com',
    classifiers=[
        'Framework :: Scrapy',
        'Intended Audience :: Developers',
        'Programming Language :: Python :: 3.10',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ],
    python_requires='>=3.7',
    install_requires=[
        'scrapy>=1.6.0',
    ],
)
